@@ -1,3 +1,5 @@
+#include <sip.h>
+
 #include <QCoreApplication>
 #include <QFile>
 #include <QLibraryInfo>
@@ -14,6 +16,10 @@ int main(int argc, char **argv)
 
     QTextStream out(&outf);
 
+    // This allows the version of sip.h to be checked against the code
+    // generator.
+    out << SIP_VERSION_STR << '\n';
+
     // This is not a feature and needs to be handled separately.
 #if defined(QT_SHARED) || defined(QT_DLL)
     out << "shared\n";
